#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COSPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COSPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/cospi.hpp>

#endif
